@@ -21,17 +21,12 @@
 This file implements test cases for itb_pango.py
 '''
 
+from typing import TYPE_CHECKING
 import sys
 import os
 import logging
 import unittest
 
-# pylint: disable=wrong-import-position
-from gi import require_version as gi_require_version
-gi_require_version('Gdk', '3.0')
-from gi.repository import Gdk # type: ignore
-# pylint: enable=wrong-import-position
-
 LOGGER = logging.getLogger('ibus-typing-booster')
 
 IMPORT_DISTRO_SUCCESSFUL = False
@@ -41,11 +36,18 @@ try:
 except (ImportError,):
     IMPORT_DISTRO_SUCCESSFUL = False
 
-# pylint: disable=wrong-import-position
+# pylint: disable=wrong-import-position,import-error
 sys.path.insert(0, "../engine")
-import itb_pango # pylint: disable=import-error
+from itb_gtk import Gdk # type: ignore
+if TYPE_CHECKING:
+    # These imports are only for type checkers (mypy). They must not be
+    # executed at runtime because itb_gtk controls the Gtk/Gdk versions.
+    # pylint: disable=reimported
+    from gi.repository import Gdk  # type: ignore
+    # pylint: enable=reimported
+import itb_pango
 sys.path.pop(0)
-# pylint: enable=wrong-import-position
+# pylint: enable=wrong-import-position,import-error
 
 # pylint: disable=missing-class-docstring
 # pylint: disable=missing-function-docstring
@@ -71,7 +73,7 @@ class ItbPangoTestCase(unittest.TestCase):
         pass
 
     def font_available_or_skip(self, font_family_name: str) -> None:
-        if not font_family_name in itb_pango.get_available_font_names():
+        if font_family_name not in itb_pango.get_available_font_names():
             self.skipTest(f'{font_family_name} is not available.')
 
     def test_dummy(self) -> None:
